@@ -8,25 +8,32 @@
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
+from enum import Enum
 
-class CounterType(object):
+
+class CounterType(Enum):
     """
     Types of counters that measure different types of metrics
     """
+    # Counters that measure execution time intervals
     Interval = 0
+    # Counters that keeps the latest measured value
     LastValue = 1
+    # Counters that measure min/average/max statistics
     Statistics = 2
+    # Counter that record timestamps
     Timestamp = 3
+    # Counter that increment counters
     Increment = 4
 
     @staticmethod
     def to_string(typ):
         if typ == CounterType.Interval:
-            return "INTERVAL" 
+            return "INTERVAL"
         if typ == CounterType.LastValue:
-            return "LAST" 
+            return "LAST"
         if typ == CounterType.Statistics:
-            return "STATS" 
+            return "STATS"
         if typ == CounterType.Timestamp:
             return "TIME"
         if typ == CounterType.Increment:
