@@ -7,11 +7,10 @@
     :license: MIT, see LICENSE for more details.
 """
 
-import pytest
-import sys, os
+from pip_services3_commons.config import ConfigParams
 
 from pip_services3_components.config import JsonConfigReader
-from pip_services3_commons.config import ConfigParams
+
 
 class TestJsonConfigReader:
 
